@@ -20,13 +20,14 @@ sub new {
     # @options argvs [String] data      Entire email message
     # @options argvs [Array]  load      User defined MTA module list
     # @options argvs [Array]  order     The order of MTA modules
+    # @options argvs [Array]  field     Email header names to be captured
     # @options argvs [Code]   hook      Reference to callback method
     # @return        [Sisimai::Message] Structured email data or Undef if each
     #                                   value of the arguments are missing
     my $class = shift;
     my $argvs = { @_ };
-    my $input = $argvs->{'input'} // 'email';
-    my $email = $argvs->{'data'} // '';
+    my $input = $argvs->{'input'}   // 'email';
+    my $email = $argvs->{'data'}    // '';
     my $child = undef;
 
     if( $input eq 'email' ) {
@@ -50,7 +51,11 @@ sub new {
         return undef;
     }
 
-    my $methodargv = { 'data' => $email, 'hook' => $argvs->{'hook'} // undef };
+    my $methodargv = {
+        'data'  => $email,
+        'hook'  => $argvs->{'hook'}  // undef,
+        'field' => $argvs->{'field'} // [],
+    };
     my $datasource = undef;
     my $mesgobject = undef;
 
@@ -147,16 +152,34 @@ method like the following codes:
 
     my $cmethod = sub {
         my $argv = shift;
-        my $data = { 'x-mailer' => '' };
+        my $data = {
+            'queue-id' => '',
+            'x-mailer' => '',
+            'precedence' => '',
+        };
 
-        if( $argv->{'message'} =~ m/^X-Mailer:\s*(.+)$/m ) {
-            $data->{'x-mailer'} = $1;
+        # Header part of the bounced mail
+        for my $e ( 'x-mailer', 'precedence' ) {
+            next unless exists $argv->{'headers'}->{ $e };
+            $data->{ $e } = $argv->{'headers'}->{ $e };
+        }
+
+        # Message body of the bounced email
+        if( $argv->{'message'} =~ m/^X-Postfix-Queue-ID:\s*(.+)$/m ) {
+            $data->{'queue-id'} = $1;
         }
 
         return $data;
     };
-    my $message = Sisimai::Message->new('data' => $mailtxt, 'hook' => $cmethod);
+
+    my $message = Sisimai::Message->new(
+        'data' => $mailtxt, 
+        'hook' => $cmethod,
+        'field' => ['X-Mailer', 'Precedence']
+    );
     print $message->catch->{'x-mailer'};    # Apple Mail (2.1283)
+    print $message->catch->{'queue-id'};    # 2DAEB222022E
+    print $message->catch->{'precedence'};  # bulk
 
 =head1 INSTANCE METHODS
 
@@ -200,7 +223,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
